"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var lit_element_1 = require("lit-element");
var highcharts_1 = tslib_1.__importDefault(require("highcharts"));
/**
 * @element highcharts-chart
 *
 * @fires load - Event fired after the chart is created. The `detail` arg will hold the created chart
 */
var HighchartsWebComponent = /** @class */ (function (_super) {
    tslib_1.__extends(HighchartsWebComponent, _super);
    function HighchartsWebComponent() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        /**
         * String for constructor method. Official constructors:
         *  - 'chart' for Highcharts charts
         *  - 'stockChart' for Highstock charts
         *  - 'mapChart' for Highmaps charts
         *  - 'ganttChart' for Gantt charts
         */
        _this.constructorType = "chart";
        /**
         * Used to pass the Highcharts instance after modules are initialized.
         * If not set the component will try to get the Highcharts from window.
         */
        _this.highcharts = highcharts_1.default;
        /**
         * This wrapper uses chart.update() method to apply new options
         * to the chart when changing the parent component.
         * This option allow to turn off the updating.
         */
        _this.allowChartUpdate = true;
        /**
         * Reinitialises the chart on prop update (as oppose to chart.update())
         * useful in some cases but slower than a regular update.
         */
        _this.immutable = false;
        /**
         * Array of update()'s function optional arguments.
         * Parameters should be defined in the same order like in
         * native Highcharts function: [redraw, oneToOne, animation].
         * (Here)[https://api.highcharts.com/class-reference/Highcharts.Chart#update] is a more specific description of the parameters.
         */
        _this.updateArgs = [
            true,
            true,
            true
        ];
        return _this;
    }
    HighchartsWebComponent.prototype.firstUpdated = function () {
        this.createChart();
    };
    HighchartsWebComponent.prototype.updated = function () {
        var _a;
        if (this.allowChartUpdate !== false) {
            if (!this.immutable && this.chart) {
                (_a = this.chart).update.apply(_a, tslib_1.__spread([this.options], (this.updateArgs || [true, true])));
            }
            else {
                this.createChart();
            }
        }
    };
    HighchartsWebComponent.prototype.render = function () {
        return lit_element_1.html(templateObject_1 || (templateObject_1 = tslib_1.__makeTemplateObject(["\n        <div></div>\n      "], ["\n        <div></div>\n      "])));
    };
    HighchartsWebComponent.prototype.createChart = function () {
        var H = this.highcharts;
        var constructorType = this.constructorType;
        if (!H) {
            console.warn('The "highcharts" property was not passed.');
        }
        else if (!H[constructorType]) {
            console.warn('The "constructorType" property is incorrect or some ' +
                "required module is not imported.");
        }
        else if (!this.options) {
            console.warn('The "options" property was not passed.');
        }
        else {
            // Create a chart
            this.chart = H[constructorType](this.chartContainer, this.options, this.chartCreated.bind(this));
        }
    };
    HighchartsWebComponent.prototype.chartCreated = function (chart) {
        var e = new CustomEvent('load', {
            detail: chart
        });
        this.dispatchEvent(e);
    };
    HighchartsWebComponent.prototype.disconnectedCallback = function () {
        if (this.chart) {
            this.chart.destroy();
            this.chart = null;
        }
    };
    tslib_1.__decorate([
        lit_element_1.property({ type: String })
    ], HighchartsWebComponent.prototype, "constructorType", void 0);
    tslib_1.__decorate([
        lit_element_1.property({ attribute: false })
    ], HighchartsWebComponent.prototype, "highcharts", void 0);
    tslib_1.__decorate([
        lit_element_1.property({ attribute: false })
    ], HighchartsWebComponent.prototype, "options", void 0);
    tslib_1.__decorate([
        lit_element_1.property({ type: Boolean })
    ], HighchartsWebComponent.prototype, "allowChartUpdate", void 0);
    tslib_1.__decorate([
        lit_element_1.property({ type: Boolean })
    ], HighchartsWebComponent.prototype, "immutable", void 0);
    tslib_1.__decorate([
        lit_element_1.property({ attribute: false })
    ], HighchartsWebComponent.prototype, "updateArgs", void 0);
    tslib_1.__decorate([
        lit_element_1.query("div")
    ], HighchartsWebComponent.prototype, "chartContainer", void 0);
    HighchartsWebComponent = tslib_1.__decorate([
        lit_element_1.customElement("highcharts-chart")
    ], HighchartsWebComponent);
    return HighchartsWebComponent;
}(lit_element_1.LitElement));
exports.default = HighchartsWebComponent;
var templateObject_1;
//# sourceMappingURL=highcharts-wc.js.map